# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: library/cpp/actors/protos/interconnect.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,library/cpp/actors/protos/interconnect.proto\x12\x13NActorsInterconnect\x1a&library/cpp/actors/protos/actors.proto\x1a google/protobuf/descriptor.proto\"2\n\x0eTEvResolveNode\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x10\n\x08\x44\x65\x61\x64line\x18\x02 \x01(\x04\"<\n\x0bTEvNodeInfo\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\"\xda\x01\n\rTNodeLocation\x12\x19\n\rDataCenterNum\x18\x01 \x01(\rB\x02\x18\x01\x12\x13\n\x07RoomNum\x18\x02 \x01(\rB\x02\x18\x01\x12\x13\n\x07RackNum\x18\x03 \x01(\rB\x02\x18\x01\x12\x13\n\x07\x42odyNum\x18\x04 \x01(\rB\x02\x18\x01\x12\x12\n\x04\x42ody\x18\x94\x91\x06 \x01(\rB\x02\x18\x01\x12\x1a\n\nDataCenter\x18\n \x01(\tB\x06\xc2\xcc\x18\x02\x44\x43\x12\x15\n\x06Module\x18\x14 \x01(\tB\x05\xc2\xcc\x18\x01M\x12\x13\n\x04Rack\x18\x1e \x01(\tB\x05\xc2\xcc\x18\x01R\x12\x13\n\x04Unit\x18( \x01(\tB\x05\xc2\xcc\x18\x01U\"8\n\rTClusterUUIDs\x12\x13\n\x0b\x43lusterUUID\x18\x01 \x01(\t\x12\x12\n\nAcceptUUID\x18\x02 \x03(\t\"\"\n\x08TScopeId\x12\n\n\x02X1\x18\x01 \x01(\x06\x12\n\n\x02X2\x18\x02 \x01(\x06\"\x9c\x04\n\x11THandshakeRequest\x12\x10\n\x08Protocol\x18\x01 \x02(\x04\x12\x12\n\nProgramPID\x18\x02 \x02(\x04\x12\x18\n\x10ProgramStartTime\x18\x03 \x02(\x04\x12\x0e\n\x06Serial\x18\x04 \x02(\x04\x12\x16\n\x0eReceiverNodeId\x18\x05 \x02(\r\x12\x15\n\rSenderActorId\x18\x06 \x02(\t\x12\x16\n\x0eSenderHostName\x18\x07 \x01(\t\x12\x18\n\x10ReceiverHostName\x18\x08 \x01(\t\x12\x0c\n\x04UUID\x18\t \x01(\t\x12\x38\n\x0c\x43lusterUUIDs\x18\r \x01(\x0b\x32\".NActorsInterconnect.TClusterUUIDs\x12\x0f\n\x07\x42\x61llast\x18\n \x01(\x0c\x12\x12\n\nVersionTag\x18\x0b \x01(\t\x12\x1b\n\x13\x41\x63\x63\x65ptedVersionTags\x18\x0c \x03(\t\x12\x19\n\x11RequireEncryption\x18\x0e \x01(\x08\x12\x34\n\rClientScopeId\x18\x0f \x01(\x0b\x32\x1d.NActorsInterconnect.TScopeId\x12\x0e\n\x06\x43ookie\x18\x10 \x01(\t\x12\x15\n\rDoCheckCookie\x18\x11 \x01(\x08\x12\x1a\n\x12RequestModernFrame\x18\x12 \x01(\x08\x12\x17\n\x0fRequestAuthOnly\x18\x13 \x01(\x08\x12\x1f\n\x17RequestExtendedTraceFmt\x18\x14 \x01(\x08\"\xfb\x02\n\x11THandshakeSuccess\x12\x10\n\x08Protocol\x18\x01 \x02(\x04\x12\x12\n\nProgramPID\x18\x02 \x02(\x04\x12\x18\n\x10ProgramStartTime\x18\x03 \x02(\x04\x12\x0e\n\x06Serial\x18\x04 \x02(\x04\x12\x15\n\rSenderActorId\x18\x05 \x02(\t\x12\x12\n\nVersionTag\x18\x06 \x01(\t\x12\x1b\n\x13\x41\x63\x63\x65ptedVersionTags\x18\x07 \x03(\t\x12\x38\n\x0c\x43lusterUUIDs\x18\x08 \x01(\x0b\x32\".NActorsInterconnect.TClusterUUIDs\x12\x17\n\x0fStartEncryption\x18\t \x01(\x08\x12\x34\n\rServerScopeId\x18\n \x01(\x0b\x32\x1d.NActorsInterconnect.TScopeId\x12\x16\n\x0eUseModernFrame\x18\x0b \x01(\x08\x12\x10\n\x08\x41uthOnly\x18\x0c \x01(\x08\x12\x1b\n\x13UseExtendedTraceFmt\x18\r \x01(\x08\"\x80\x01\n\x0fTHandshakeReply\x12\x37\n\x07Success\x18\x01 \x01(\x0b\x32&.NActorsInterconnect.THandshakeSuccess\x12\x19\n\x11\x45rrorExplaination\x18\x02 \x01(\t\x12\x19\n\x11\x43ookieCheckResult\x18\x03 \x01(\x08\"\x96\x01\n\x0eTEvLoadMessage\x12\x36\n\x04Hops\x18\x01 \x03(\x0b\x32(.NActorsInterconnect.TEvLoadMessage.THop\x12\n\n\x02Id\x18\x03 \x01(\t\x12\x0f\n\x07Payload\x18\x04 \x01(\x0c\x1a/\n\x04THop\x12\'\n\x07NextHop\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId:2\n\tPrintName\x12\x1d.google.protobuf.FieldOptions\x18\xc8\x89\x03 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'library.cpp.actors.protos.interconnect_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(PrintName)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TNODELOCATION.fields_by_name['DataCenterNum']._options = None
  _TNODELOCATION.fields_by_name['DataCenterNum']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['RoomNum']._options = None
  _TNODELOCATION.fields_by_name['RoomNum']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['RackNum']._options = None
  _TNODELOCATION.fields_by_name['RackNum']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['BodyNum']._options = None
  _TNODELOCATION.fields_by_name['BodyNum']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['Body']._options = None
  _TNODELOCATION.fields_by_name['Body']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['DataCenter']._options = None
  _TNODELOCATION.fields_by_name['DataCenter']._serialized_options = b'\302\314\030\002DC'
  _TNODELOCATION.fields_by_name['Module']._options = None
  _TNODELOCATION.fields_by_name['Module']._serialized_options = b'\302\314\030\001M'
  _TNODELOCATION.fields_by_name['Rack']._options = None
  _TNODELOCATION.fields_by_name['Rack']._serialized_options = b'\302\314\030\001R'
  _TNODELOCATION.fields_by_name['Unit']._options = None
  _TNODELOCATION.fields_by_name['Unit']._serialized_options = b'\302\314\030\001U'
  _TEVRESOLVENODE._serialized_start=143
  _TEVRESOLVENODE._serialized_end=193
  _TEVNODEINFO._serialized_start=195
  _TEVNODEINFO._serialized_end=255
  _TNODELOCATION._serialized_start=258
  _TNODELOCATION._serialized_end=476
  _TCLUSTERUUIDS._serialized_start=478
  _TCLUSTERUUIDS._serialized_end=534
  _TSCOPEID._serialized_start=536
  _TSCOPEID._serialized_end=570
  _THANDSHAKEREQUEST._serialized_start=573
  _THANDSHAKEREQUEST._serialized_end=1113
  _THANDSHAKESUCCESS._serialized_start=1116
  _THANDSHAKESUCCESS._serialized_end=1495
  _THANDSHAKEREPLY._serialized_start=1498
  _THANDSHAKEREPLY._serialized_end=1626
  _TEVLOADMESSAGE._serialized_start=1629
  _TEVLOADMESSAGE._serialized_end=1779
  _TEVLOADMESSAGE_THOP._serialized_start=1732
  _TEVLOADMESSAGE_THOP._serialized_end=1779
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/health.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/health.proto\x12\rNKikimrHealth\"\"\n\x04TRaw\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x04\"\x7f\n\tTPathLeaf\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\r\n\x05SetAt\x18\x02 \x01(\x04\x12/\n\rPreviousValue\x18\x03 \x01(\x0b\x32\x18.NKikimrHealth.TPathLeaf\x12$\n\x05\x43olor\x18\x04 \x01(\x0e\x32\x15.NKikimrHealth.EColor\"\x81\x01\n\tTPathNode\x12 \n\x03Raw\x18\x01 \x01(\x0b\x32\x13.NKikimrHealth.TRaw\x12*\n\x08\x43hildren\x18\x02 \x03(\x0b\x32\x18.NKikimrHealth.TPathNode\x12&\n\x04Leaf\x18\x03 \x01(\x0b\x32\x18.NKikimrHealth.TPathLeaf\"5\n\x0bTHealthTree\x12&\n\x04Root\x18\x01 \x01(\x0b\x32\x18.NKikimrHealth.TPathNode\"R\n\x0bTNodeGossip\x12\x19\n\x11\x43reationInstantMs\x18\x01 \x01(\x04\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x18\n\x10StartupInstantMs\x18\x03 \x01(\x04\"\xa0\x01\n\rTEvPushStatus\x12\x19\n\x11\x43reationInstantMs\x18\x01 \x01(\x04\x12\x14\n\x0cSenderNodeId\x18\x02 \x01(\r\x12.\n\nNodeGossip\x18\x03 \x03(\x0b\x32\x1a.NKikimrHealth.TNodeGossip\x12.\n\nHealthTree\x18\x04 \x01(\x0b\x32\x1a.NKikimrHealth.THealthTree*\x1c\n\x06\x45\x43olor\x12\x07\n\x03Red\x10\x00\x12\t\n\x05Green\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.health_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ECOLOR._serialized_start=646
  _ECOLOR._serialized_end=674
  _TRAW._serialized_start=47
  _TRAW._serialized_end=81
  _TPATHLEAF._serialized_start=83
  _TPATHLEAF._serialized_end=210
  _TPATHNODE._serialized_start=213
  _TPATHNODE._serialized_end=342
  _THEALTHTREE._serialized_start=344
  _THEALTHTREE._serialized_end=397
  _TNODEGOSSIP._serialized_start=399
  _TNODEGOSSIP._serialized_end=481
  _TEVPUSHSTATUS._serialized_start=484
  _TEVPUSHSTATUS._serialized_end=644
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/grpc_pq_old.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/grpc_pq_old.proto\x12\x0fNKikimrPQClient\"\'\n\tTKeyValue\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"5\n\x08TMapType\x12)\n\x05Items\x18\x01 \x03(\x0b\x32\x1a.NKikimrPQClient.TKeyValue\"\xfb\x02\n\nTDataChunk\x12\x38\n\x04Meta\x18| \x01(\x0b\x32*.NKikimrPQClient.TDataChunk.TSessionHeader\x12\r\n\x05SeqNo\x18\x01 \x01(\x04\x12\x12\n\nCreateTime\x18\x03 \x01(\x04\x12\n\n\x02Ip\x18\x08 \x01(\x0c\x12\x42\n\tChunkType\x18\t \x01(\x0e\x32&.NKikimrPQClient.TDataChunk.EChunkType:\x07REGULAR\x12\r\n\x05\x43odec\x18\n \x01(\x03\x12.\n\x0b\x45xtraFields\x18~ \x01(\x0b\x32\x19.NKikimrPQClient.TMapType\x12\x0c\n\x04\x44\x61ta\x18\x7f \x01(\x0c\x1aN\n\x0eTSessionHeader\x12\x0e\n\x06Server\x18\x01 \x01(\t\x12\x0c\n\x04\x46ile\x18\x02 \x01(\t\x12\r\n\x05Ident\x18\x03 \x01(\t\x12\x0f\n\x07LogType\x18\x04 \x01(\t\"#\n\nEChunkType\x12\x0b\n\x07REGULAR\x10\x00\x12\x08\n\x04GROW\x10\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.grpc_pq_old_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TKEYVALUE._serialized_start=54
  _TKEYVALUE._serialized_end=93
  _TMAPTYPE._serialized_start=95
  _TMAPTYPE._serialized_end=148
  _TDATACHUNK._serialized_start=151
  _TDATACHUNK._serialized_end=530
  _TDATACHUNK_TSESSIONHEADER._serialized_start=415
  _TDATACHUNK_TSESSIONHEADER._serialized_end=493
  _TDATACHUNK_ECHUNKTYPE._serialized_start=495
  _TDATACHUNK_ECHUNKTYPE._serialized_end=530
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/labeled_counters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/core/protos/labeled_counters.proto\x12\x16NKikimrLabeledCounters\x1a\x1eydb/core/protos/counters.proto\x1a\x1cydb/core/protos/tablet.proto\"\x99\x01\n\x1fTEvTabletLabeledCountersRequest\x12\x39\n\nTabletType\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\r\n\x05Group\x18\x02 \x01(\t\x12\x18\n\x10LabeledCounterId\x18\x03 \x01(\x04\x12\x12\n\x07Version\x18\x04 \x01(\r:\x01\x31\"\xd3\x01\n\x15TTabletLabeledCounter\x12\r\n\x05Value\x18\x01 \x01(\x04\x12\n\n\x02Id\x18\x02 \x01(\x04\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x45\n\rAggregateFunc\x18\x04 \x01(\x0e\x32..NKikimr.TLabeledCounterOptions.EAggregateFunc\x12:\n\x04Type\x18\x05 \x01(\x0e\x32,.NKikimr.TLabeledCounterOptions.ECounterType\x12\x0e\n\x06NameId\x18\x06 \x01(\r\"\x95\x01\n\x16TTabletLabeledCounters\x12\r\n\x05Group\x18\x01 \x01(\t\x12\x12\n\nGroupNames\x18\x02 \x01(\t\x12\x45\n\x0eLabeledCounter\x18\x03 \x03(\x0b\x32-.NKikimrLabeledCounters.TTabletLabeledCounter\x12\x11\n\tDelimiter\x18\x04 \x01(\t\"\x97\x01\n TEvTabletLabeledCountersResponse\x12N\n\x16LabeledCountersByGroup\x18\x01 \x03(\x0b\x32..NKikimrLabeledCounters.TTabletLabeledCounters\x12\r\n\x05Nodes\x18\x02 \x03(\r\x12\x14\n\x0c\x43ounterNames\x18\x03 \x03(\tB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.labeled_counters_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TEVTABLETLABELEDCOUNTERSREQUEST._serialized_start=129
  _TEVTABLETLABELEDCOUNTERSREQUEST._serialized_end=282
  _TTABLETLABELEDCOUNTER._serialized_start=285
  _TTABLETLABELEDCOUNTER._serialized_end=496
  _TTABLETLABELEDCOUNTERS._serialized_start=499
  _TTABLETLABELEDCOUNTERS._serialized_end=648
  _TEVTABLETLABELEDCOUNTERSRESPONSE._serialized_start=651
  _TEVTABLETLABELEDCOUNTERSRESPONSE._serialized_end=802
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/flat_tx_scheme.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import type_info_pb2 as ydb_dot_core_dot_protos_dot_type__info__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.public.api.protos import ydb_cms_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__cms__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/flat_tx_scheme.proto\x12\rNKikimrScheme\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1fydb/core/protos/type_info.proto\x1a ydb/core/protos/subdomains.proto\x1a/ydb/core/protos/bind_channel_storage_pool.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a#ydb/public/api/protos/ydb_cms.proto\"1\n\rTSchemeConfig\x12 \n\x18PipeClientCachePoolLimit\x18\x01 \x01(\x04\"x\n\x07TConfig\x12-\n\x07\x43urrent\x18\x01 \x01(\x0b\x32\x1c.NKikimrScheme.TSchemeConfig\x12>\n\x18\x44\x65\x66\x61ultSchemeShardConfig\x18\x03 \x01(\x0b\x32\x1c.NKikimrScheme.TSchemeConfig\"\xa8\x01\n\x1aTEvModifySchemeTransaction\x12\x33\n\x0bTransaction\x18\x01 \x03(\x0b\x32\x1e.NKikimrSchemeOp.TModifyScheme\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\x12\r\n\x05Owner\x18\x05 \x01(\t\x12\x13\n\x0b\x46\x61ilOnExist\x18\x06 \x01(\x08\x12\x11\n\tUserToken\x18\x07 \x01(\t\"W\n)TFetcherCheckUserTieringPermissionsResult\x12\x16\n\x0eOperationAllow\x18\x01 \x01(\x08\x12\x12\n\nDenyReason\x18\x02 \x01(\t\"f\n#TFetcherCheckUserTieringPermissions\x12\x11\n\tUserToken\x18\x01 \x01(\x0c\x12\x16\n\x0eTieringRuleIds\x18\x02 \x03(\t\x12\x14\n\x0c\x41\x63tivityType\x18\x03 \x01(\t\"7\n\x14TEvProcessingRequest\x12\x11\n\tClassName\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\"\xdb\x01\n\x15TEvProcessingResponse\x12@\n\x07\x43ontent\x18\x01 \x01(\x0b\x32-.NKikimrScheme.TEvProcessingResponse.TContentH\x00\x12<\n\x05\x45rror\x18\x02 \x01(\x0b\x32+.NKikimrScheme.TEvProcessingResponse.TErrorH\x00\x1a\x18\n\x08TContent\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x1a\x1e\n\x06TError\x12\x14\n\x0c\x45rrorMessage\x18\x01 \x01(\tB\x08\n\x06Result\"\xbd\x01\n TEvModifySchemeTransactionResult\x12&\n\x06Status\x18\x01 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\x12\x0e\n\x06Reason\x18\x02 \x01(\t\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x15\n\rSchemeshardId\x18\x04 \x01(\x04\x12\x0e\n\x06PathId\x18\x05 \x01(\x04\x12\x16\n\x0ePathCreateTxId\x18\x06 \x01(\x04\x12\x14\n\x0cPathDropTxId\x18\x07 \x01(\x04\"\xdc\x02\n\x17TEvDescribeSchemeResult\x12&\n\x06Status\x18\x01 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\x12\x0e\n\x06Reason\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12:\n\x0fPathDescription\x18\x04 \x01(\x0b\x32!.NKikimrSchemeOp.TPathDescription\x12\x11\n\tPathOwner\x18\x05 \x01(\x06\x12\x0e\n\x06PathId\x18\x06 \x01(\x06\x12\x1d\n\x15LastExistedPrefixPath\x18\x07 \x01(\t\x12\x1f\n\x17LastExistedPrefixPathId\x18\x08 \x01(\x06\x12G\n\x1cLastExistedPrefixDescription\x18\t \x01(\x0b\x32!.NKikimrSchemeOp.TPathDescription\x12\x13\n\x0bPathOwnerId\x18\n \x01(\x06\"T\n\x0bTEvCancelTx\x12\x12\n\nTargetTxId\x18\x01 \x01(\x04\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x15\n\rSecurityToken\x18\x03 \x01(\t\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\"m\n\x11TEvCancelTxResult\x12&\n\x06Status\x18\x01 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\x12\x0e\n\x06Result\x18\x02 \x01(\t\x12\x12\n\nTargetTxId\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\"a\n\x0fTEvUpdateConfig\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12&\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x16.NKikimrScheme.TConfig\"c\n\x15TEvUpdateConfigResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Reason\x18\x03 \x01(\t\"*\n\x08TEvLogin\x12\x0c\n\x04User\x18\x01 \x01(\t\x12\x10\n\x08Password\x18\x02 \x01(\t\".\n\x0eTEvLoginResult\x12\r\n\x05\x45rror\x18\x01 \x01(\t\x12\r\n\x05Token\x18\x02 \x01(\t\"%\n\x15TEvNotifyTxCompletion\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"/\n\x1fTEvNotifyTxCompletionRegistered\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"+\n\x1bTEvNotifyTxCompletionResult\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\x98\x03\n\rTSchemeLimits\x12\x10\n\x08MaxDepth\x18\x01 \x01(\x04\x12\x10\n\x08MaxPaths\x18\x02 \x01(\x04\x12\x18\n\x10MaxChildrenInDir\x18\x03 \x01(\x04\x12\x17\n\x0fMaxAclBytesSize\x18\x04 \x01(\x04\x12\x17\n\x0fMaxTableColumns\x18\x05 \x01(\x04\x12 \n\x18MaxTableColumnNameLength\x18\x06 \x01(\x04\x12\x1a\n\x12MaxTableKeyColumns\x18\x07 \x01(\x04\x12\x17\n\x0fMaxTableIndices\x18\x08 \x01(\x04\x12\x11\n\tMaxShards\x18\t \x01(\x04\x12\x17\n\x0fMaxShardsInPath\x18\n \x01(\x04\x12 \n\x18MaxConsistentCopyTargets\x18\x0b \x01(\x04\x12\x1c\n\x14MaxPathElementLength\x18\x0c \x01(\x04\x12\x1f\n\x17\x45xtraPathSymbolsAllowed\x18\r \x01(\t\x12\x17\n\x0fMaxPQPartitions\x18\x0e \x01(\x04\x12\x1a\n\x12MaxTableCdcStreams\x18\x0f \x01(\x04\"\x82\x05\n\x18TEvInitTenantSchemeShard\x12\x19\n\x11\x44omainSchemeShard\x18\x01 \x01(\x06\x12\x14\n\x0c\x44omainPathId\x18\x02 \x01(\x06\x12\x10\n\x08RootPath\x18\x03 \x01(\t\x12\r\n\x05Owner\x18\x04 \x01(\t\x12\x14\n\x0c\x45\x66\x66\x65\x63tiveACL\x18\x05 \x01(\x0c\x12\x1b\n\x13\x45\x66\x66\x65\x63tiveACLVersion\x18\x06 \x01(\x04\x12>\n\x10ProcessingParams\x18\x07 \x01(\x0b\x32$.NKikimrSubDomains.TProcessingParams\x12\x36\n\x0cStoragePools\x18\x08 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\x12\x37\n\x0eUserAttributes\x18\t \x03(\x0b\x32\x1f.NKikimrSchemeOp.TUserAttribute\x12\x1d\n\x15UserAttributesVersion\x18\n \x01(\x04\x12\x32\n\x0cSchemeLimits\x18\x0b \x01(\x0b\x32\x1c.NKikimrScheme.TSchemeLimits\x12\x19\n\x11InitiateMigration\x18\x0c \x01(\x08\x12\x1e\n\x16ResourcesDomainOwnerId\x18\r \x01(\x06\x12\x1d\n\x15ResourcesDomainPathId\x18\x0e \x01(\x06\x12\x12\n\nSharedHive\x18\x0f \x01(\x06\x12>\n\x14\x44\x65\x63laredSchemeQuotas\x18\x10 \x01(\x0b\x32 .NKikimrSubDomains.TSchemeQuotas\x12/\n\x0e\x44\x61tabaseQuotas\x18\x11 \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\"c\n\x1eTEvInitTenantSchemeShardResult\x12\x19\n\x11TenantSchemeShard\x18\x01 \x01(\x04\x12&\n\x06Status\x18\x02 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\",\n\x08TShardID\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x06\x12\x0f\n\x07LocalId\x18\x02 \x01(\x04\"\x97\x01\n\rTMigrateShard\x12)\n\x08ShardIdx\x18\x01 \x01(\x0b\x32\x17.NKikimrScheme.TShardID\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\x10\n\x08TabletId\x18\x03 \x01(\x06\x12;\n\x11\x42indedStoragePool\x18\x04 \x03(\x0b\x32 .NKikimrStoragePool.TChannelBind\"\xcc\x02\n\x0cTMigratePath\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12+\n\x0cParentPathId\x18\x02 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x10\n\x08PathType\x18\x04 \x01(\r\x12\x13\n\x0bStepCreated\x18\x05 \x01(\x04\x12\x12\n\nCreateTxId\x18\x06 \x01(\x06\x12\r\n\x05Owner\x18\x07 \x01(\t\x12\x0b\n\x03\x41\x43L\x18\x08 \x01(\t\x12\x17\n\x0f\x44irAlterVersion\x18\t \x01(\x04\x12\x1d\n\x15UserAttrsAlterVersion\x18\n \x01(\x04\x12\x12\n\nACLVersion\x18\x0b \x01(\x04\x12\x37\n\x0eUserAttributes\x18\x0c \x03(\x0b\x32\x1f.NKikimrSchemeOp.TUserAttribute\"\xf8\x01\n\x0eTMigrateColumn\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0f\n\x07\x43olType\x18\x03 \x01(\r\x12,\n\x0b\x43olTypeInfo\x18\x0b \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x12\x13\n\x0b\x43olKeyOrder\x18\x04 \x01(\r\x12\x15\n\rCreateVersion\x18\x05 \x01(\x04\x12\x15\n\rDeleteVersion\x18\x06 \x01(\x04\x12\x0e\n\x06\x46\x61mily\x18\x07 \x01(\r\x12\x13\n\x0b\x44\x65\x66\x61ultKind\x18\x08 \x01(\r\x12\x14\n\x0c\x44\x65\x66\x61ultValue\x18\t \x01(\x0c\x12\x0f\n\x07NotNull\x18\n \x01(\x08\"u\n\x11TMigratePartition\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x10\n\x08RangeEnd\x18\x02 \x01(\t\x12)\n\x08ShardIdx\x18\x03 \x01(\x0b\x32\x17.NKikimrScheme.TShardID\x12\x17\n\x0fPartitionConfig\x18\x04 \x01(\t\"\xfb\x01\n\rTMigrateTable\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x11\n\tNextColId\x18\x02 \x01(\r\x12\x17\n\x0fPartitionConfig\x18\x03 \x01(\t\x12\x14\n\x0c\x41lterVersion\x18\x04 \x01(\r\x12\x1b\n\x13PartitioningVersion\x18\x05 \x01(\r\x12.\n\x07\x43olumns\x18\x06 \x03(\x0b\x32\x1d.NKikimrScheme.TMigrateColumn\x12\x34\n\nPartitions\x18\x07 \x03(\x0b\x32 .NKikimrScheme.TMigratePartition\"|\n\x12TMigrateTableIndex\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x14\n\x0c\x41lterVersion\x18\x02 \x01(\x04\x12\x0c\n\x04Type\x18\x03 \x01(\r\x12\r\n\x05State\x18\x04 \x01(\r\x12\x0c\n\x04Keys\x18\x05 \x03(\t\"W\n\rTMigrateKesus\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x12\x0e\n\x06\x43onfig\x18\x03 \x01(\t\"\xc9\x02\n\nTEvMigrate\x12\x1d\n\x15SchemeShardGeneration\x18\x01 \x01(\x04\x12)\n\x04Path\x18\x02 \x01(\x0b\x32\x1b.NKikimrScheme.TMigratePath\x12\x32\n\x0bPathVersion\x18\x03 \x01(\x0b\x32\x1d.NKikimrSchemeOp.TPathVersion\x12,\n\x06Shards\x18\x04 \x03(\x0b\x32\x1c.NKikimrScheme.TMigrateShard\x12+\n\x05Table\x18\x05 \x01(\x0b\x32\x1c.NKikimrScheme.TMigrateTable\x12\x35\n\nTableIndex\x18\x06 \x01(\x0b\x32!.NKikimrScheme.TMigrateTableIndex\x12+\n\x05Kesus\x18\x07 \x01(\x0b\x32\x1c.NKikimrScheme.TMigrateKesus\"\x9e\x01\n\x10TEvMigrateResult\x12\x19\n\x11TenantSchemeShard\x18\x01 \x01(\x06\x12\x1d\n\x15SchemeShardGeneration\x18\x02 \x01(\x04\x12%\n\x06PathId\x18\x03 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12)\n\x08ShardIds\x18\x04 \x03(\x0b\x32\x17.NKikimrScheme.TShardID\"7\n\x1aTEvPublishTenantAsReadOnly\x12\x19\n\x11\x44omainSchemeShard\x18\x01 \x01(\x06\"e\n TEvPublishTenantAsReadOnlyResult\x12\x19\n\x11TenantSchemeShard\x18\x01 \x01(\x06\x12&\n\x06Status\x18\x02 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\"Y\n\x0fTEvRewriteOwner\x12\x11\n\tPrevOwner\x18\x01 \x01(\x06\x12\x10\n\x08NewOwner\x18\x02 \x01(\x06\x12\x12\n\nGeneration\x18\x03 \x01(\x04\x12\r\n\x05Round\x18\x04 \x01(\x04\"?\n\x15TEvRewriteOwnerResult\x12&\n\x06Status\x18\x01 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\"-\n\x10TEvPublishTenant\x12\x19\n\x11\x44omainSchemeShard\x18\x01 \x01(\x06\"3\n\x16TEvPublishTenantResult\x12\x19\n\x11TenantSchemeShard\x18\x01 \x01(\x06\"\x92\x02\n\x18TEvSyncTenantSchemeShard\x12\x19\n\x11\x44omainSchemeShard\x18\x01 \x01(\x06\x12\x14\n\x0c\x44omainPathId\x18\x02 \x01(\x06\x12\x10\n\x08TabletID\x18\x03 \x01(\x06\x12\x12\n\nGeneration\x18\x04 \x01(\x04\x12\x1b\n\x13\x45\x66\x66\x65\x63tiveACLVersion\x18\x05 \x01(\x04\x12\x18\n\x10SubdomainVersion\x18\x06 \x01(\x04\x12\x1d\n\x15UserAttributesVersion\x18\x07 \x01(\x04\x12\x12\n\nTenantHive\x18\x08 \x01(\x04\x12\x1e\n\x16TenantSysViewProcessor\x18\t \x01(\x04\x12\x15\n\rTenantRootACL\x18\n \x01(\t\"\xf0\x03\n\x1aTEvUpdateTenantSchemeShard\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\r\n\x05Owner\x18\x03 \x01(\t\x12\x14\n\x0c\x45\x66\x66\x65\x63tiveACL\x18\x04 \x01(\x0c\x12\x1b\n\x13\x45\x66\x66\x65\x63tiveACLVersion\x18\x05 \x01(\x04\x12\x36\n\x0cStoragePools\x18\x06 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\x12\x18\n\x10SubdomainVersion\x18\x07 \x01(\x04\x12\x37\n\x0eUserAttributes\x18\x08 \x03(\x0b\x32\x1f.NKikimrSchemeOp.TUserAttribute\x12\x1d\n\x15UserAttributesVersion\x18\t \x01(\x04\x12\x12\n\nTenantHive\x18\n \x01(\x04\x12\x1e\n\x16TenantSysViewProcessor\x18\x0b \x01(\x04\x12>\n\x14\x44\x65\x63laredSchemeQuotas\x18\x0c \x01(\x0b\x32 .NKikimrSubDomains.TSchemeQuotas\x12/\n\x0e\x44\x61tabaseQuotas\x18\x0e \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x12\x1b\n\x13UpdateTenantRootACL\x18\r \x01(\t\"0\n\x1cTEvFindTabletSubDomainPathId\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\"\x83\x02\n\"TEvFindTabletSubDomainPathIdResult\x12I\n\x06Status\x18\x01 \x01(\x0e\x32\x39.NKikimrScheme.TEvFindTabletSubDomainPathIdResult.EStatus\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\x15\n\rSchemeShardId\x18\x03 \x01(\x04\x12\x17\n\x0fSubDomainPathId\x18\x04 \x01(\x04\"P\n\x07\x45Status\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x13\n\x0fSHARD_NOT_FOUND\x10\x02\x12\x12\n\x0ePATH_NOT_FOUND\x10\x03*\x84\x04\n\x07\x45Status\x12\x11\n\rStatusSuccess\x10\x00\x12\x12\n\x0eStatusAccepted\x10\x01\x12\x1a\n\x16StatusPathDoesNotExist\x10\x02\x12\x1c\n\x18StatusPathIsNotDirectory\x10\x03\x12\x17\n\x13StatusAlreadyExists\x10\x04\x12\x15\n\x11StatusSchemeError\x10\x05\x12\x16\n\x12StatusNameConflict\x10\x06\x12\x1a\n\x16StatusInvalidParameter\x10\x07\x12\x1f\n\x1bStatusMultipleModifications\x10\x08\x12\x12\n\x0eStatusReadOnly\x10\t\x12\x17\n\x13StatusTxIdNotExists\x10\n\x12\x1c\n\x18StatusTxIsNotCancellable\x10\x0b\x12\x16\n\x12StatusAccessDenied\x10\x0c\x12\x16\n\x12StatusNotAvailable\x10\r\x12\x1c\n\x18StatusPreconditionFailed\x10\x0e\x12\x18\n\x14StatusRedirectDomain\x10\x0f\x12\x17\n\x13StatusQuotaExceeded\x10\x10\x12\x1b\n\x17StatusResourceExhausted\x10\x11\x12\x14\n\x10StatusReserved18\x10\x12\x12\x14\n\x10StatusReserved19\x10\x13\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.flat_tx_scheme_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ESTATUS._serialized_start=6824
  _ESTATUS._serialized_end=7340
  _TSCHEMECONFIG._serialized_start=314
  _TSCHEMECONFIG._serialized_end=363
  _TCONFIG._serialized_start=365
  _TCONFIG._serialized_end=485
  _TEVMODIFYSCHEMETRANSACTION._serialized_start=488
  _TEVMODIFYSCHEMETRANSACTION._serialized_end=656
  _TFETCHERCHECKUSERTIERINGPERMISSIONSRESULT._serialized_start=658
  _TFETCHERCHECKUSERTIERINGPERMISSIONSRESULT._serialized_end=745
  _TFETCHERCHECKUSERTIERINGPERMISSIONS._serialized_start=747
  _TFETCHERCHECKUSERTIERINGPERMISSIONS._serialized_end=849
  _TEVPROCESSINGREQUEST._serialized_start=851
  _TEVPROCESSINGREQUEST._serialized_end=906
  _TEVPROCESSINGRESPONSE._serialized_start=909
  _TEVPROCESSINGRESPONSE._serialized_end=1128
  _TEVPROCESSINGRESPONSE_TCONTENT._serialized_start=1062
  _TEVPROCESSINGRESPONSE_TCONTENT._serialized_end=1086
  _TEVPROCESSINGRESPONSE_TERROR._serialized_start=1088
  _TEVPROCESSINGRESPONSE_TERROR._serialized_end=1118
  _TEVMODIFYSCHEMETRANSACTIONRESULT._serialized_start=1131
  _TEVMODIFYSCHEMETRANSACTIONRESULT._serialized_end=1320
  _TEVDESCRIBESCHEMERESULT._serialized_start=1323
  _TEVDESCRIBESCHEMERESULT._serialized_end=1671
  _TEVCANCELTX._serialized_start=1673
  _TEVCANCELTX._serialized_end=1757
  _TEVCANCELTXRESULT._serialized_start=1759
  _TEVCANCELTXRESULT._serialized_end=1868
  _TEVUPDATECONFIG._serialized_start=1870
  _TEVUPDATECONFIG._serialized_end=1967
  _TEVUPDATECONFIGRESULT._serialized_start=1969
  _TEVUPDATECONFIGRESULT._serialized_end=2068
  _TEVLOGIN._serialized_start=2070
  _TEVLOGIN._serialized_end=2112
  _TEVLOGINRESULT._serialized_start=2114
  _TEVLOGINRESULT._serialized_end=2160
  _TEVNOTIFYTXCOMPLETION._serialized_start=2162
  _TEVNOTIFYTXCOMPLETION._serialized_end=2199
  _TEVNOTIFYTXCOMPLETIONREGISTERED._serialized_start=2201
  _TEVNOTIFYTXCOMPLETIONREGISTERED._serialized_end=2248
  _TEVNOTIFYTXCOMPLETIONRESULT._serialized_start=2250
  _TEVNOTIFYTXCOMPLETIONRESULT._serialized_end=2293
  _TSCHEMELIMITS._serialized_start=2296
  _TSCHEMELIMITS._serialized_end=2704
  _TEVINITTENANTSCHEMESHARD._serialized_start=2707
  _TEVINITTENANTSCHEMESHARD._serialized_end=3349
  _TEVINITTENANTSCHEMESHARDRESULT._serialized_start=3351
  _TEVINITTENANTSCHEMESHARDRESULT._serialized_end=3450
  _TSHARDID._serialized_start=3452
  _TSHARDID._serialized_end=3496
  _TMIGRATESHARD._serialized_start=3499
  _TMIGRATESHARD._serialized_end=3650
  _TMIGRATEPATH._serialized_start=3653
  _TMIGRATEPATH._serialized_end=3985
  _TMIGRATECOLUMN._serialized_start=3988
  _TMIGRATECOLUMN._serialized_end=4236
  _TMIGRATEPARTITION._serialized_start=4238
  _TMIGRATEPARTITION._serialized_end=4355
  _TMIGRATETABLE._serialized_start=4358
  _TMIGRATETABLE._serialized_end=4609
  _TMIGRATETABLEINDEX._serialized_start=4611
  _TMIGRATETABLEINDEX._serialized_end=4735
  _TMIGRATEKESUS._serialized_start=4737
  _TMIGRATEKESUS._serialized_end=4824
  _TEVMIGRATE._serialized_start=4827
  _TEVMIGRATE._serialized_end=5156
  _TEVMIGRATERESULT._serialized_start=5159
  _TEVMIGRATERESULT._serialized_end=5317
  _TEVPUBLISHTENANTASREADONLY._serialized_start=5319
  _TEVPUBLISHTENANTASREADONLY._serialized_end=5374
  _TEVPUBLISHTENANTASREADONLYRESULT._serialized_start=5376
  _TEVPUBLISHTENANTASREADONLYRESULT._serialized_end=5477
  _TEVREWRITEOWNER._serialized_start=5479
  _TEVREWRITEOWNER._serialized_end=5568
  _TEVREWRITEOWNERRESULT._serialized_start=5570
  _TEVREWRITEOWNERRESULT._serialized_end=5633
  _TEVPUBLISHTENANT._serialized_start=5635
  _TEVPUBLISHTENANT._serialized_end=5680
  _TEVPUBLISHTENANTRESULT._serialized_start=5682
  _TEVPUBLISHTENANTRESULT._serialized_end=5733
  _TEVSYNCTENANTSCHEMESHARD._serialized_start=5736
  _TEVSYNCTENANTSCHEMESHARD._serialized_end=6010
  _TEVUPDATETENANTSCHEMESHARD._serialized_start=6013
  _TEVUPDATETENANTSCHEMESHARD._serialized_end=6509
  _TEVFINDTABLETSUBDOMAINPATHID._serialized_start=6511
  _TEVFINDTABLETSUBDOMAINPATHID._serialized_end=6559
  _TEVFINDTABLETSUBDOMAINPATHIDRESULT._serialized_start=6562
  _TEVFINDTABLETSUBDOMAINPATHIDRESULT._serialized_end=6821
  _TEVFINDTABLETSUBDOMAINPATHIDRESULT_ESTATUS._serialized_start=6741
  _TEVFINDTABLETSUBDOMAINPATHIDRESULT_ESTATUS._serialized_end=6821
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/s3/proto/range.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ydb/library/yql/providers/s3/proto/range.proto\x12\x08NYql.NS3\"\xbc\x01\n\x06TRange\x12\x16\n\x0e\x44\x65precatedPath\x18\x02 \x03(\t\x12\x16\n\x0eStartPathIndex\x18\x03 \x01(\x04\x12%\n\x05Paths\x18\x04 \x03(\x0b\x32\x16.NYql.NS3.TRange.TPath\x1a[\n\x05TPath\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12(\n\x08\x43hildren\x18\x02 \x03(\x0b\x32\x16.NYql.NS3.TRange.TPath\x12\x0c\n\x04Size\x18\x03 \x01(\x04\x12\x0c\n\x04Read\x18\x04 \x01(\x08\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.s3.proto.range_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TRANGE._serialized_start=61
  _TRANGE._serialized_end=249
  _TRANGE_TPATH._serialized_start=158
  _TRANGE_TPATH._serialized_end=249
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blob_depot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blob_depot_config_pb2 as ydb_dot_core_dot_protos_dot_blob__depot__config__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import blobstorage_disk_color_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__color__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ydb/core/protos/blob_depot.proto\x12\x10NKikimrBlobDepot\x1a\'ydb/core/protos/blob_depot_config.proto\x1a\x1aydb/core/protos/base.proto\x1a,ydb/core/protos/blobstorage_disk_color.proto\"N\n\nTBlobSeqId\x12\x0f\n\x07\x43hannel\x18\x01 \x01(\r\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0c\n\x04Step\x18\x03 \x01(\r\x12\r\n\x05Index\x18\x04 \x01(\r\"\x8b\x01\n\x0cTBlobLocator\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12/\n\tBlobSeqId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobDepot.TBlobSeqId\x12\x10\n\x08\x43hecksum\x18\x03 \x01(\r\x12\x14\n\x0cTotalDataLen\x18\x04 \x01(\x04\x12\x11\n\tFooterLen\x18\x05 \x01(\r\"j\n\x0bTValueChain\x12/\n\x07Locator\x18\x01 \x01(\x0b\x32\x1e.NKikimrBlobDepot.TBlobLocator\x12\x15\n\rSubrangeBegin\x18\x02 \x01(\x04\x12\x13\n\x0bSubrangeEnd\x18\x03 \x01(\x04\"\xa5\x01\n\x06TValue\x12\x0c\n\x04Meta\x18\x01 \x01(\x0c\x12\x31\n\nValueChain\x18\x02 \x03(\x0b\x32\x1d.NKikimrBlobDepot.TValueChain\x12/\n\tKeepState\x18\x03 \x01(\x0e\x32\x1c.NKikimrBlobDepot.EKeepState\x12\x0e\n\x06Public\x18\x04 \x01(\x08\x12\x19\n\x11GoingToAssimilate\x18\x05 \x01(\x08\"\x93\x01\n\rTGivenIdRange\x12\x44\n\rChannelRanges\x18\x01 \x03(\x0b\x32-.NKikimrBlobDepot.TGivenIdRange.TChannelRange\x1a<\n\rTChannelRange\x12\x0f\n\x07\x43hannel\x18\x01 \x01(\r\x12\r\n\x05\x42\x65gin\x18\x02 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x03 \x01(\x04\"}\n\x13TResolvedValueChain\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12)\n\x06\x42lobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x15\n\rSubrangeBegin\x18\x03 \x01(\r\x12\x13\n\x0bSubrangeEnd\x18\x04 \x01(\r\"R\n\x0eTEvApplyConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x32\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\".NKikimrBlobDepot.TBlobDepotConfig\"6\n\x14TEvApplyConfigResult\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"C\n\x10TEvRegisterAgent\x12\x16\n\x0eVirtualGroupId\x18\x01 \x01(\r\x12\x17\n\x0f\x41gentInstanceId\x18\x02 \x01(\x06\"\xbf\x03\n\x16TEvRegisterAgentResult\x12\x12\n\nGeneration\x18\x01 \x01(\r\x12K\n\x0c\x43hannelKinds\x18\x02 \x03(\x0b\x32\x35.NKikimrBlobDepot.TEvRegisterAgentResult.TChannelKind\x12\x17\n\x0f\x44\x65\x63ommitGroupId\x18\x03 \x01(\r\x12:\n\nSpaceColor\x18\x04 \x01(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\x12!\n\x19\x41pproximateFreeSpaceShare\x18\x05 \x01(\x02\x1a\x33\n\x0fTChannelGroupId\x12\x0f\n\x07\x43hannel\x18\x01 \x01(\r\x12\x0f\n\x07GroupId\x18\x02 \x01(\r\x1a\x96\x01\n\x0cTChannelKind\x12\x35\n\x0b\x43hannelKind\x18\x01 \x01(\x0e\x32 .NKikimrBlobDepot.TChannelKind.E\x12O\n\rChannelGroups\x18\x02 \x03(\x0b\x32\x38.NKikimrBlobDepot.TEvRegisterAgentResult.TChannelGroupId\"V\n\x0eTEvAllocateIds\x12\x35\n\x0b\x43hannelKind\x18\x01 \x01(\x0e\x32 .NKikimrBlobDepot.TChannelKind.E\x12\r\n\x05\x43ount\x18\x02 \x01(\r\"\x98\x01\n\x14TEvAllocateIdsResult\x12\x35\n\x0b\x43hannelKind\x18\x01 \x01(\x0e\x32 .NKikimrBlobDepot.TChannelKind.E\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x35\n\x0cGivenIdRange\x18\x03 \x01(\x0b\x32\x1f.NKikimrBlobDepot.TGivenIdRange\"K\n\x08TEvBlock\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x19\n\x11\x42lockedGeneration\x18\x02 \x01(\r\x12\x12\n\nIssuerGuid\x18\x03 \x01(\x04\"g\n\x0eTEvBlockResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12\x14\n\x0cTimeToLiveMs\x18\x03 \x01(\r\"\xa7\x03\n\rTEvPushNotify\x12\x46\n\x0e\x42lockedTablets\x18\x01 \x03(\x0b\x32..NKikimrBlobDepot.TEvPushNotify.TBlockedTablet\x12J\n\x10InvalidatedSteps\x18\x02 \x03(\x0b\x32\x30.NKikimrBlobDepot.TEvPushNotify.TInvalidatedStep\x12:\n\nSpaceColor\x18\x03 \x01(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\x12!\n\x19\x41pproximateFreeSpaceShare\x18\x04 \x01(\x02\x1aQ\n\x0eTBlockedTablet\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x19\n\x11\x42lockedGeneration\x18\x02 \x01(\r\x12\x12\n\nIssuerGuid\x18\x03 \x01(\x04\x1aP\n\x10TInvalidatedStep\x12\x0f\n\x07\x43hannel\x18\x01 \x01(\r\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x17\n\x0fInvalidatedStep\x18\x03 \x01(\r\"W\n\x13TEvPushNotifyResult\x12\x34\n\x0eWritesInFlight\x18\x01 \x03(\x0b\x32\x1c.NKikimrBlobDepot.TBlobSeqId\x12\n\n\x02Id\x18\x02 \x01(\x04\"#\n\x0eTEvQueryBlocks\x12\x11\n\tTabletIds\x18\x01 \x03(\x06\"H\n\x14TEvQueryBlocksResult\x12\x1a\n\x12\x42lockedGenerations\x18\x01 \x03(\r\x12\x14\n\x0cTimeToLiveMs\x18\x02 \x01(\r\"\xfd\x01\n\x11TEvCollectGarbage\x12\'\n\x04Keep\x18\x01 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12,\n\tDoNotKeep\x18\x02 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\x12\x12\n\nGeneration\x18\x04 \x01(\r\x12\x1c\n\x14PerGenerationCounter\x18\x05 \x01(\r\x12\x0f\n\x07\x43hannel\x18\x06 \x01(\r\x12\x0c\n\x04Hard\x18\x07 \x01(\x08\x12\x19\n\x11\x43ollectGeneration\x18\x08 \x01(\r\x12\x13\n\x0b\x43ollectStep\x18\t \x01(\x04\"Z\n\x17TEvCollectGarbageResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\"\xd3\x01\n\x10TEvCommitBlobSeq\x12\x37\n\x05Items\x18\x01 \x03(\x0b\x32(.NKikimrBlobDepot.TEvCommitBlobSeq.TItem\x1a\x85\x01\n\x05TItem\x12\x33\n\x0b\x42lobLocator\x18\x01 \x01(\x0b\x32\x1e.NKikimrBlobDepot.TBlobLocator\x12\x0b\n\x03Key\x18\x02 \x01(\x0c\x12\x0c\n\x04Meta\x18\x03 \x01(\x0c\x12\x16\n\x0eUncertainWrite\x18\x04 \x01(\x08\x12\x14\n\x0c\x43ommitNotify\x18\x05 \x01(\x08\"\xa1\x01\n\x16TEvCommitBlobSeqResult\x12=\n\x05Items\x18\x01 \x03(\x0b\x32..NKikimrBlobDepot.TEvCommitBlobSeqResult.TItem\x1aH\n\x05TItem\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\"G\n\x18TEvDiscardSpoiledBlobSeq\x12+\n\x05Items\x18\x01 \x03(\x0b\x32\x1c.NKikimrBlobDepot.TBlobSeqId\"\xbf\x03\n\nTEvResolve\x12\x31\n\x05Items\x18\x01 \x03(\x0b\x32\".NKikimrBlobDepot.TEvResolve.TItem\x1a\x9e\x01\n\tTKeyRange\x12\x14\n\x0c\x42\x65ginningKey\x18\x01 \x01(\x0c\x12\x1e\n\x10IncludeBeginning\x18\x02 \x01(\x08:\x04true\x12\x11\n\tEndingKey\x18\x03 \x01(\x0c\x12\x1c\n\rIncludeEnding\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x12\n\x07MaxKeys\x18\x05 \x01(\r:\x01\x30\x12\x16\n\x07Reverse\x18\x06 \x01(\x08:\x05\x66\x61lse\x1a\xdc\x01\n\x05TItem\x12:\n\x08KeyRange\x18\x01 \x01(\x0b\x32&.NKikimrBlobDepot.TEvResolve.TKeyRangeH\x00\x12\x12\n\x08\x45xactKey\x18\x02 \x01(\x0cH\x00\x12\x19\n\nReturnMeta\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x0cReturnOwners\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x10\n\x08TabletId\x18\x06 \x01(\x06\x12\x18\n\x10MustRestoreFirst\x18\x07 \x01(\x08\x42\x0f\n\rKeyDesignator\"\xb6\x02\n\x10TEvResolveResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12\x45\n\x0cResolvedKeys\x18\x03 \x03(\x0b\x32/.NKikimrBlobDepot.TEvResolveResult.TResolvedKey\x1a\x99\x01\n\x0cTResolvedKey\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\x12\x0b\n\x03Key\x18\x02 \x01(\x0c\x12\x39\n\nValueChain\x18\x03 \x03(\x0b\x32%.NKikimrBlobDepot.TResolvedValueChain\x12\x0c\n\x04Meta\x18\x04 \x01(\x0c\x12\x0e\n\x06Owners\x18\x05 \x03(\x04\x12\x13\n\x0b\x45rrorReason\x18\x06 \x01(\t*2\n\nEKeepState\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\x08\n\x04Keep\x10\x01\x12\r\n\tDoNotKeep\x10\x02')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blob_depot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EKEEPSTATE._serialized_start=4216
  _EKEEPSTATE._serialized_end=4266
  _TBLOBSEQID._serialized_start=169
  _TBLOBSEQID._serialized_end=247
  _TBLOBLOCATOR._serialized_start=250
  _TBLOBLOCATOR._serialized_end=389
  _TVALUECHAIN._serialized_start=391
  _TVALUECHAIN._serialized_end=497
  _TVALUE._serialized_start=500
  _TVALUE._serialized_end=665
  _TGIVENIDRANGE._serialized_start=668
  _TGIVENIDRANGE._serialized_end=815
  _TGIVENIDRANGE_TCHANNELRANGE._serialized_start=755
  _TGIVENIDRANGE_TCHANNELRANGE._serialized_end=815
  _TRESOLVEDVALUECHAIN._serialized_start=817
  _TRESOLVEDVALUECHAIN._serialized_end=942
  _TEVAPPLYCONFIG._serialized_start=944
  _TEVAPPLYCONFIG._serialized_end=1026
  _TEVAPPLYCONFIGRESULT._serialized_start=1028
  _TEVAPPLYCONFIGRESULT._serialized_end=1082
  _TEVREGISTERAGENT._serialized_start=1084
  _TEVREGISTERAGENT._serialized_end=1151
  _TEVREGISTERAGENTRESULT._serialized_start=1154
  _TEVREGISTERAGENTRESULT._serialized_end=1601
  _TEVREGISTERAGENTRESULT_TCHANNELGROUPID._serialized_start=1397
  _TEVREGISTERAGENTRESULT_TCHANNELGROUPID._serialized_end=1448
  _TEVREGISTERAGENTRESULT_TCHANNELKIND._serialized_start=1451
  _TEVREGISTERAGENTRESULT_TCHANNELKIND._serialized_end=1601
  _TEVALLOCATEIDS._serialized_start=1603
  _TEVALLOCATEIDS._serialized_end=1689
  _TEVALLOCATEIDSRESULT._serialized_start=1692
  _TEVALLOCATEIDSRESULT._serialized_end=1844
  _TEVBLOCK._serialized_start=1846
  _TEVBLOCK._serialized_end=1921
  _TEVBLOCKRESULT._serialized_start=1923
  _TEVBLOCKRESULT._serialized_end=2026
  _TEVPUSHNOTIFY._serialized_start=2029
  _TEVPUSHNOTIFY._serialized_end=2452
  _TEVPUSHNOTIFY_TBLOCKEDTABLET._serialized_start=2289
  _TEVPUSHNOTIFY_TBLOCKEDTABLET._serialized_end=2370
  _TEVPUSHNOTIFY_TINVALIDATEDSTEP._serialized_start=2372
  _TEVPUSHNOTIFY_TINVALIDATEDSTEP._serialized_end=2452
  _TEVPUSHNOTIFYRESULT._serialized_start=2454
  _TEVPUSHNOTIFYRESULT._serialized_end=2541
  _TEVQUERYBLOCKS._serialized_start=2543
  _TEVQUERYBLOCKS._serialized_end=2578
  _TEVQUERYBLOCKSRESULT._serialized_start=2580
  _TEVQUERYBLOCKSRESULT._serialized_end=2652
  _TEVCOLLECTGARBAGE._serialized_start=2655
  _TEVCOLLECTGARBAGE._serialized_end=2908
  _TEVCOLLECTGARBAGERESULT._serialized_start=2910
  _TEVCOLLECTGARBAGERESULT._serialized_end=3000
  _TEVCOMMITBLOBSEQ._serialized_start=3003
  _TEVCOMMITBLOBSEQ._serialized_end=3214
  _TEVCOMMITBLOBSEQ_TITEM._serialized_start=3081
  _TEVCOMMITBLOBSEQ_TITEM._serialized_end=3214
  _TEVCOMMITBLOBSEQRESULT._serialized_start=3217
  _TEVCOMMITBLOBSEQRESULT._serialized_end=3378
  _TEVCOMMITBLOBSEQRESULT_TITEM._serialized_start=3306
  _TEVCOMMITBLOBSEQRESULT_TITEM._serialized_end=3378
  _TEVDISCARDSPOILEDBLOBSEQ._serialized_start=3380
  _TEVDISCARDSPOILEDBLOBSEQ._serialized_end=3451
  _TEVRESOLVE._serialized_start=3454
  _TEVRESOLVE._serialized_end=3901
  _TEVRESOLVE_TKEYRANGE._serialized_start=3520
  _TEVRESOLVE_TKEYRANGE._serialized_end=3678
  _TEVRESOLVE_TITEM._serialized_start=3681
  _TEVRESOLVE_TITEM._serialized_end=3901
  _TEVRESOLVERESULT._serialized_start=3904
  _TEVRESOLVERESULT._serialized_end=4214
  _TEVRESOLVERESULT_TRESOLVEDKEY._serialized_start=4061
  _TEVRESOLVERESULT_TRESOLVEDKEY._serialized_end=4214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/s3/proto/sink.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/library/yql/providers/s3/proto/sink.proto\x12\x08NYql.NS3\"\x9f\x02\n\x05TSink\x12\x0b\n\x03Url\x18\x01 \x01(\t\x12\r\n\x05Token\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12\x0c\n\x04Keys\x18\x04 \x03(\t\x12\x18\n\x0b\x43ompression\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bMemoryLimit\x18\x06 \x01(\x04H\x01\x88\x01\x01\x12#\n\x16MaxFileSize_deprecated\x18\x07 \x01(\x04H\x02\x88\x01\x01\x12\x16\n\tExtension\x18\x08 \x01(\tH\x03\x88\x01\x01\x12\x16\n\tMultipart\x18\t \x01(\x08H\x04\x88\x01\x01\x42\x0e\n\x0c_CompressionB\x0e\n\x0c_MemoryLimitB\x19\n\x17_MaxFileSize_deprecatedB\x0c\n\n_ExtensionB\x0c\n\n_MultipartB\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.s3.proto.sink_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TSINK._serialized_start=60
  _TSINK._serialized_end=347
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/s3/proto/retry_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ydb/library/yql/providers/s3/proto/retry_config.proto\x12\x08NYql.NS3\"j\n\x0cTRetryConfig\x12\x16\n\x0eInitialDelayMs\x18\x01 \x01(\x04\x12\x19\n\x11MaxRetriesPerPath\x18\x02 \x01(\r\x12\x0f\n\x07\x45psilon\x18\x03 \x01(\x01\x12\x16\n\x0eMaxRetryTimeMs\x18\x04 \x01(\x04\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.s3.proto.retry_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TRETRYCONFIG._serialized_start=67
  _TRETRYCONFIG._serialized_end=173
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/drivemodel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ydb/core/protos/drivemodel.proto\x12\x12NKikimrBlobStorage\"\x8a\x07\n\x0bTDriveModel\x12\x17\n\x0cSeekTimeNsec\x18\n \x01(\x04:\x01\x30\x12!\n\x16\x42ulkReadBlockSizeBytes\x18\x1e \x01(\x04:\x01\x30\x12\"\n\x17\x42ulkWriteBlockSizeBytes\x18( \x01(\x04:\x01\x30\x12\x17\n\x0cTrimSpeedBps\x18\x32 \x01(\x04:\x01\x30\x12\x1b\n\x10TotalChunksCount\x18< \x01(\x04:\x01\x30\x12\x17\n\x0cSpeedBpsRead\x18\x46 \x01(\x04:\x01\x30\x12\x18\n\rSpeedBpsWrite\x18P \x01(\x04:\x01\x30\x12\x1a\n\x0fSpeedBpsMinRead\x18Z \x01(\x04:\x01\x30\x12\x1b\n\x10SpeedBpsMinWrite\x18\x64 \x01(\x04:\x01\x30\x12\x1a\n\x0fSpeedBpsMaxRead\x18n \x01(\x04:\x01\x30\x12\x1b\n\x10SpeedBpsMaxWrite\x18x \x01(\x04:\x01\x30\x12!\n\x15OptimalQueueDepthRead\x18\x82\x01 \x01(\x04:\x01\x30\x12\"\n\x16OptimalQueueDepthWrite\x18\x8c\x01 \x01(\x04:\x01\x30\x12\x1f\n\x13GlueingDeadlineRead\x18\x96\x01 \x01(\x04:\x01\x30\x12 \n\x14GlueingDeadlineWrite\x18\xa0\x01 \x01(\x04:\x01\x30\x12O\n\x0bModelSource\x18\xf2\x07 \x01(\x0e\x32,.NKikimrBlobStorage.TDriveModel.EModelSource:\x0bSourceClear\x12\x1c\n\x11SourceModelNumber\x18\xfc\x07 \x01(\t:\x00\x12!\n\x16SourceFirmwareRevision\x18\x86\x08 \x01(\t:\x00\x12\x1d\n\x12SourceSerialNumber\x18\x90\x08 \x01(\t:\x00\x12)\n\x19IsSourceWriteCacheEnabled\x18\x9a\x08 \x01(\x08:\x05\x66\x61lse\x12$\n\x14IsSourceSharedWithOs\x18\xa4\x08 \x01(\x08:\x05\x66\x61lse\x12\"\n\x12IsSourceSolidState\x18\xae\x08 \x01(\x08:\x05\x66\x61lse\"\x8f\x01\n\x0c\x45ModelSource\x12\x0f\n\x0bSourceClear\x10\x00\x12\x19\n\x15SourceGenericHardcode\x10\x01\x12\x1c\n\x18SourceMatchingIdHardcode\x10\x02\x12\x16\n\x12SourceLocalMeasure\x10\x03\x12\x1d\n\x19SourceConfigForMatchingId\x10\x04\"F\n\x0fTDriveModelList\x12\x33\n\nDriveModel\x18\n \x03(\x0b\x32\x1f.NKikimrBlobStorage.TDriveModelB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.drivemodel_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TDRIVEMODEL._serialized_start=57
  _TDRIVEMODEL._serialized_end=963
  _TDRIVEMODEL_EMODELSOURCE._serialized_start=820
  _TDRIVEMODEL_EMODELSOURCE._serialized_end=963
  _TDRIVEMODELLIST._serialized_start=965
  _TDRIVEMODELLIST._serialized_end=1035
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_hive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ydb/core/protos/counters_hive.proto\x12\rNKikimr.NHive\x1a\x1eydb/core/protos/counters.proto*\xff\x05\n\x0f\x45SimpleCounters\x12-\n\x15\x43OUNTER_TABLETS_TOTAL\x10\x00\x1a\x12\x82\xd6\x1b\x0e\n\x0cTabletsTotal\x12-\n\x15\x43OUNTER_TABLETS_ALIVE\x10\x01\x1a\x12\x82\xd6\x1b\x0e\n\x0cTabletsAlive\x12/\n\x16\x43OUNTER_BOOTQUEUE_SIZE\x10\x02\x1a\x13\x82\xd6\x1b\x0f\n\rBootQueueSize\x12\'\n\x12\x43OUNTER_STATE_DONE\x10\x03\x1a\x0f\x82\xd6\x1b\x0b\n\tStateDone\x12:\n\x1a\x43OUNTER_RESPONSE_TIME_USEC\x10\x04\x1a\x1a\x82\xd6\x1b\x16\n\x14ResponseTimeMicrosec\x12\x31\n\x17\x43OUNTER_METRICS_COUNTER\x10\x05\x1a\x14\x82\xd6\x1b\x10\n\x0eMetricsCounter\x12)\n\x13\x43OUNTER_METRICS_CPU\x10\x06\x1a\x10\x82\xd6\x1b\x0c\n\nMetricsCPU\x12/\n\x16\x43OUNTER_METRICS_MEMORY\x10\x07\x1a\x13\x82\xd6\x1b\x0f\n\rMetricsMemory\x12\x31\n\x17\x43OUNTER_METRICS_NETWORK\x10\x08\x1a\x14\x82\xd6\x1b\x10\n\x0eMetricsNetwork\x12\x31\n\x17\x43OUNTER_BALANCE_SCATTER\x10\t\x1a\x14\x82\xd6\x1b\x10\n\x0e\x42\x61lanceScatter\x12/\n\x16\x43OUNTER_WAITQUEUE_SIZE\x10\n\x1a\x13\x82\xd6\x1b\x0f\n\rWaitQueueSize\x12\x34\n\x19\x43OUNTER_BALANCE_USAGE_MIN\x10\x0b\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42\x61lanceUsageMin\x12\x34\n\x19\x43OUNTER_BALANCE_USAGE_MAX\x10\x0c\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42\x61lanceUsageMax\x12-\n\x15\x43OUNTER_SEQUENCE_FREE\x10\r\x1a\x12\x82\xd6\x1b\x0e\n\x0cSequenceFree\x12\x37\n\x1a\x43OUNTER_SEQUENCE_ALLOCATED\x10\x0e\x1a\x17\x82\xd6\x1b\x13\n\x11SequenceAllocated*\x85\x05\n\x13\x45\x43umulativeCounters\x12\x39\n\x1b\x43OUNTER_BOOTQUEUE_PROCESSED\x10\x00\x1a\x18\x82\xd6\x1b\x14\n\x12\x42ootQueueProcessed\x12/\n\x16\x43OUNTER_BOOTQUEUE_TIME\x10\x01\x1a\x13\x82\xd6\x1b\x0f\n\rBootQueueTime\x12\x35\n\x19\x43OUNTER_AUTOKICK_EXECUTED\x10\x02\x1a\x16\x82\xd6\x1b\x12\n\x10\x41utokickExecuted\x12\x31\n\x17\x43OUNTER_AUTOKICK_FAILED\x10\x03\x1a\x14\x82\xd6\x1b\x10\n\x0e\x41utokickFailed\x12\x35\n\x19\x43OUNTER_BALANCER_EXECUTED\x10\x04\x1a\x16\x82\xd6\x1b\x12\n\x10\x42\x61lancerExecuted\x12\x31\n\x17\x43OUNTER_BALANCER_FAILED\x10\x05\x1a\x14\x82\xd6\x1b\x10\n\x0e\x42\x61lancerFailed\x12/\n\x16\x43OUNTER_DRAIN_EXECUTED\x10\x06\x1a\x13\x82\xd6\x1b\x0f\n\rDrainExecuted\x12+\n\x14\x43OUNTER_DRAIN_FAILED\x10\x07\x1a\x11\x82\xd6\x1b\r\n\x0b\x44rainFailed\x12-\n\x15\x43OUNTER_FILL_EXECUTED\x10\x08\x1a\x12\x82\xd6\x1b\x0e\n\x0c\x46illExecuted\x12-\n\x15\x43OUNTER_TABLETS_MOVED\x10\t\x1a\x12\x82\xd6\x1b\x0e\n\x0cTabletsMoved\x12\x36\n\x1a\x43OUNTER_SUGGESTED_SCALE_UP\x10\n\x1a\x16\x82\xd6\x1b\x12\n\x10SuggestedScaleUp\x12:\n\x1c\x43OUNTER_SUGGESTED_SCALE_DOWN\x10\x0b\x1a\x18\x82\xd6\x1b\x14\n\x12SuggestedScaleDown*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\xa5\x19\n\x08\x45TxTypes\x12.\n\x14TXTYPE_CREATE_TABLET\x10\x00\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxCreateTablet\x12,\n\x13TXTYPE_SYNC_TABLETS\x10\x01\x1a\x13\x8a\xd6\x1b\x0f\n\rTxSyncTablets\x12*\n\x12TXTYPE_KILL_TABLET\x10\x02\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxKillTablet\x12\x39\n\x1aTXTYPE_UPDATE_TABLET_GROUP\x10\x03\x1a\x19\x8a\xd6\x1b\x15\n\x13TxUpdateTabletGroup\x12;\n\x1bTXTYPE_UPDATE_TABLET_STATUS\x10\x04\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxUpdateTabletStatus\x12.\n\x14TXTYPE_REGISTER_NODE\x10\x05\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxRegisterNode\x12&\n\x10TXTYPE_KILL_NODE\x10\x06\x1a\x10\x8a\xd6\x1b\x0c\n\nTxKillNode\x12,\n\x13TXTYPE_ADOPT_TABLET\x10\x07\x1a\x13\x8a\xd6\x1b\x0f\n\rTxAdoptTablet\x12;\n\x1bTXTYPE_UPDATE_TABLET_METRIC\x10\x08\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxUpdateTabletMetric\x12;\n\x1bTXTYPE_UPDATE_TABLET_GROUPS\x10\t\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxUpdateTabletGroups\x12\x41\n\x1eTXTYPE_UNLOCK_TABLET_EXECUTION\x10\n\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxUnlockTabletExecution\x12\x32\n\x16TXTYPE_REASSIGN_GROUPS\x10\x0b\x1a\x16\x8a\xd6\x1b\x12\n\x10TxReassignGroups\x12=\n\x1cTXTYPE_LOCK_TABLET_EXECUTION\x10\x0c\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxLockTabletExecution\x12\x32\n\x16TXTYPE_LOAD_EVERYTHING\x10\r\x1a\x16\x8a\xd6\x1b\x12\n\x10TxLoadEverything\x12*\n\x12TXTYPE_INIT_SCHEME\x10\x0e\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitScheme\x12;\n\x1bTXTYPE_DELETE_TABLET_RESULT\x10\x0f\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxDeleteTabletResult\x12.\n\x14TXTYPE_DELETE_TABLET\x10\x10\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxDeleteTablet\x12\x37\n\x19TXTYPE_CUT_TABLET_HISTORY\x10\x11\x1a\x18\x8a\xd6\x1b\x14\n\x12TxCutTabletHistory\x12;\n\x1bTXTYPE_BLOCK_STORAGE_RESULT\x10\x12\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxBlockStorageResult\x12\x41\n\x1eTXTYPE_REQUEST_TABLET_SEQUENCE\x10\x13\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxRequestTabletSequence\x12\x43\n\x1fTXTYPE_RESPONSE_TABLET_SEQUENCE\x10\x14\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxResponseTabletSequence\x12G\n!TXTYPE_PROCESS_PENDING_OPERATIONS\x10\x15\x1a \x8a\xd6\x1b\x1c\n\x1aTxProcessPendingOperations\x12+\n\x13TXTYPE_MON_DB_STATE\x10\x16\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonDbState\x12-\n\x14TXTYPE_MON_MEM_STATE\x10\x17\x1a\x13\x8a\xd6\x1b\x0f\n\rTxMonMemState\x12.\n\x14TXTYPE_MON_RESOURCES\x10\x18\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxMonResources\x12,\n\x13TXTYPE_MON_SETTINGS\x10\x19\x1a\x13\x8a\xd6\x1b\x0f\n\rTxMonSettings\x12*\n\x12TXTYPE_MON_LANDING\x10\x1a\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonLanding\x12\x33\n\x17TXTYPE_MON_LANDING_DATA\x10\x1b\x1a\x16\x8a\xd6\x1b\x12\n\x10TxMonLandingData\x12+\n\x13TXTYPE_MON_SET_DOWN\x10\x1c\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonSetDown\x12/\n\x15TXTYPE_MON_SET_FREEZE\x10\x1d\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxMonSetFreeze\x12-\n\x14TXTYPE_MON_KICK_NODE\x10\x1e\x1a\x13\x8a\xd6\x1b\x0f\n\rTxMonKickNode\x12.\n\x14TXTYPE_MON_REBALANCE\x10\x1f\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxMonRebalance\x12\x39\n\x1aTXTYPE_MON_REASSIGN_TABLET\x10 \x1a\x19\x8a\xd6\x1b\x15\n\x13TxMonReassignTablet\x12\x33\n\x17TXTYPE_MON_RESET_TABLET\x10!\x1a\x16\x8a\xd6\x1b\x12\n\x10TxMonResetTablet\x12(\n\x11TXTYPE_MON_GROUPS\x10\"\x1a\x11\x8a\xd6\x1b\r\n\x0bTxMonGroups\x12-\n\x14TXTYPE_MON_NOT_READY\x10#\x1a\x13\x8a\xd6\x1b\x0f\n\rTxMonNotReady\x12*\n\x12TXTYPE_MON_STORAGE\x10$\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonStorage\x12\x37\n\x19TXTYPE_PROCESS_BOOT_QUEUE\x10%\x1a\x18\x8a\xd6\x1b\x14\n\x12TxProcessBootQueue\x12!\n\rTXTYPE_STATUS\x10&\x1a\x0e\x8a\xd6\x1b\n\n\x08TxStatus\x12\x32\n\x16TXTYPE_DISCONNECT_NODE\x10\'\x1a\x16\x8a\xd6\x1b\x12\n\x10TxDisconnectNode\x12\x31\n\x16TXTYPE_MON_FIND_TABLET\x10(\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxMonFindTablet\x12.\n\x14TXTYPE_UPDATE_DOMAIN\x10)\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxUpdateDomain\x12\x31\n\x16TXTYPE_MON_STOP_TABLET\x10*\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxMonStopTablet\x12\x35\n\x18TXTYPE_MON_RESUME_TABLET\x10+\x1a\x17\x8a\xd6\x1b\x13\n\x11TxMonResumeTablet\x12:\n\x1aTXTYPE_CONFIGURE_SUBDOMAIN\x10,\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxConfigureSubdomain\x12\x37\n\x19TXTYPE_MON_INIT_MIGRATION\x10-\x1a\x18\x8a\xd6\x1b\x14\n\x12TxMonInitMigration\x12\x39\n\x1aTXTYPE_MON_QUERY_MIGRATION\x10.\x1a\x19\x8a\xd6\x1b\x15\n\x13TxMonQueryMigration\x12.\n\x14TXTYPE_SEIZE_TABLETS\x10/\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxSeizeTablets\x12\x39\n\x1aTXTYPE_SEIZE_TABLETS_REPLY\x10\x30\x1a\x19\x8a\xd6\x1b\x15\n\x13TxSeizeTabletsReply\x12\x32\n\x16TXTYPE_RELEASE_TABLETS\x10\x31\x1a\x16\x8a\xd6\x1b\x12\n\x10TxReleaseTablets\x12=\n\x1cTXTYPE_RELEASE_TABLETS_REPLY\x10\x32\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxReleaseTabletsReply\x12/\n\x15TXTYPE_MON_DRAIN_NODE\x10\x33\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxMonDrainNode\x12\x31\n\x16TXTYPE_MON_TABLET_INFO\x10\x34\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxMonTabletInfo\x12,\n\x13TXTYPE_START_TABLET\x10\x35\x1a\x13\x8a\xd6\x1b\x0f\n\rTxStartTablet\x12*\n\x12TXTYPE_STOP_TABLET\x10\x36\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxStopTablet\x12.\n\x14TXTYPE_RESUME_TABLET\x10\x37\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxResumeTablet\x12\x30\n\x15TXTYPE_RESTART_TABLET\x10\x38\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxRestartTablet\x12\x31\n\x16TXTYPE_MON_MOVE_TABLET\x10\x39\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxMonMoveTablet\x12\x39\n\x1aTXTYPE_TABLET_OWNERS_REPLY\x10:\x1a\x19\x8a\xd6\x1b\x15\n\x13TxTabletOwnersReply\x12=\n\x1cTXTYPE_REQUEST_TABLET_OWNERS\x10;\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxRequestTabletOwners\x12H\n\"TXTYPE_REASSIGN_GROUPS_ON_DECOMMIT\x10<\x1a \x8a\xd6\x1b\x1c\n\x1aTxReassignGroupsOnDecommitB \n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x04Hive')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_hive_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\004Hive'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLETS_TOTAL"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLETS_TOTAL"]._serialized_options = b'\202\326\033\016\n\014TabletsTotal'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLETS_ALIVE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLETS_ALIVE"]._serialized_options = b'\202\326\033\016\n\014TabletsAlive'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_SIZE"]._serialized_options = b'\202\326\033\017\n\rBootQueueSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STATE_DONE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STATE_DONE"]._serialized_options = b'\202\326\033\013\n\tStateDone'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._serialized_options = b'\202\326\033\026\n\024ResponseTimeMicrosec'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_COUNTER"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_COUNTER"]._serialized_options = b'\202\326\033\020\n\016MetricsCounter'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_CPU"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_CPU"]._serialized_options = b'\202\326\033\014\n\nMetricsCPU'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_MEMORY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_MEMORY"]._serialized_options = b'\202\326\033\017\n\rMetricsMemory'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_NETWORK"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_NETWORK"]._serialized_options = b'\202\326\033\020\n\016MetricsNetwork'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_SCATTER"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_SCATTER"]._serialized_options = b'\202\326\033\020\n\016BalanceScatter'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_WAITQUEUE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_WAITQUEUE_SIZE"]._serialized_options = b'\202\326\033\017\n\rWaitQueueSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_USAGE_MIN"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_USAGE_MIN"]._serialized_options = b'\202\326\033\021\n\017BalanceUsageMin'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_USAGE_MAX"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_USAGE_MAX"]._serialized_options = b'\202\326\033\021\n\017BalanceUsageMax'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_FREE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_FREE"]._serialized_options = b'\202\326\033\016\n\014SequenceFree'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_ALLOCATED"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_ALLOCATED"]._serialized_options = b'\202\326\033\023\n\021SequenceAllocated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_PROCESSED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_PROCESSED"]._serialized_options = b'\202\326\033\024\n\022BootQueueProcessed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_TIME"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_TIME"]._serialized_options = b'\202\326\033\017\n\rBootQueueTime'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_AUTOKICK_EXECUTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_AUTOKICK_EXECUTED"]._serialized_options = b'\202\326\033\022\n\020AutokickExecuted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_AUTOKICK_FAILED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_AUTOKICK_FAILED"]._serialized_options = b'\202\326\033\020\n\016AutokickFailed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BALANCER_EXECUTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BALANCER_EXECUTED"]._serialized_options = b'\202\326\033\022\n\020BalancerExecuted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BALANCER_FAILED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BALANCER_FAILED"]._serialized_options = b'\202\326\033\020\n\016BalancerFailed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DRAIN_EXECUTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DRAIN_EXECUTED"]._serialized_options = b'\202\326\033\017\n\rDrainExecuted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DRAIN_FAILED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DRAIN_FAILED"]._serialized_options = b'\202\326\033\r\n\013DrainFailed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FILL_EXECUTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FILL_EXECUTED"]._serialized_options = b'\202\326\033\016\n\014FillExecuted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TABLETS_MOVED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TABLETS_MOVED"]._serialized_options = b'\202\326\033\016\n\014TabletsMoved'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SUGGESTED_SCALE_UP"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SUGGESTED_SCALE_UP"]._serialized_options = b'\202\326\033\022\n\020SuggestedScaleUp'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SUGGESTED_SCALE_DOWN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SUGGESTED_SCALE_DOWN"]._serialized_options = b'\202\326\033\024\n\022SuggestedScaleDown'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_TABLET"]._serialized_options = b'\212\326\033\020\n\016TxCreateTablet'
  _ETXTYPES.values_by_name["TXTYPE_SYNC_TABLETS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SYNC_TABLETS"]._serialized_options = b'\212\326\033\017\n\rTxSyncTablets'
  _ETXTYPES.values_by_name["TXTYPE_KILL_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_KILL_TABLET"]._serialized_options = b'\212\326\033\016\n\014TxKillTablet'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_GROUP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_GROUP"]._serialized_options = b'\212\326\033\025\n\023TxUpdateTabletGroup'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_STATUS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_STATUS"]._serialized_options = b'\212\326\033\026\n\024TxUpdateTabletStatus'
  _ETXTYPES.values_by_name["TXTYPE_REGISTER_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REGISTER_NODE"]._serialized_options = b'\212\326\033\020\n\016TxRegisterNode'
  _ETXTYPES.values_by_name["TXTYPE_KILL_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_KILL_NODE"]._serialized_options = b'\212\326\033\014\n\nTxKillNode'
  _ETXTYPES.values_by_name["TXTYPE_ADOPT_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ADOPT_TABLET"]._serialized_options = b'\212\326\033\017\n\rTxAdoptTablet'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_METRIC"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_METRIC"]._serialized_options = b'\212\326\033\026\n\024TxUpdateTabletMetric'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_GROUPS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_GROUPS"]._serialized_options = b'\212\326\033\026\n\024TxUpdateTabletGroups'
  _ETXTYPES.values_by_name["TXTYPE_UNLOCK_TABLET_EXECUTION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UNLOCK_TABLET_EXECUTION"]._serialized_options = b'\212\326\033\031\n\027TxUnlockTabletExecution'
  _ETXTYPES.values_by_name["TXTYPE_REASSIGN_GROUPS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REASSIGN_GROUPS"]._serialized_options = b'\212\326\033\022\n\020TxReassignGroups'
  _ETXTYPES.values_by_name["TXTYPE_LOCK_TABLET_EXECUTION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOCK_TABLET_EXECUTION"]._serialized_options = b'\212\326\033\027\n\025TxLockTabletExecution'
  _ETXTYPES.values_by_name["TXTYPE_LOAD_EVERYTHING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOAD_EVERYTHING"]._serialized_options = b'\212\326\033\022\n\020TxLoadEverything'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEME"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEME"]._serialized_options = b'\212\326\033\016\n\014TxInitScheme'
  _ETXTYPES.values_by_name["TXTYPE_DELETE_TABLET_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DELETE_TABLET_RESULT"]._serialized_options = b'\212\326\033\026\n\024TxDeleteTabletResult'
  _ETXTYPES.values_by_name["TXTYPE_DELETE_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DELETE_TABLET"]._serialized_options = b'\212\326\033\020\n\016TxDeleteTablet'
  _ETXTYPES.values_by_name["TXTYPE_CUT_TABLET_HISTORY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CUT_TABLET_HISTORY"]._serialized_options = b'\212\326\033\024\n\022TxCutTabletHistory'
  _ETXTYPES.values_by_name["TXTYPE_BLOCK_STORAGE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_BLOCK_STORAGE_RESULT"]._serialized_options = b'\212\326\033\026\n\024TxBlockStorageResult'
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_TABLET_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_TABLET_SEQUENCE"]._serialized_options = b'\212\326\033\031\n\027TxRequestTabletSequence'
  _ETXTYPES.values_by_name["TXTYPE_RESPONSE_TABLET_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESPONSE_TABLET_SEQUENCE"]._serialized_options = b'\212\326\033\032\n\030TxResponseTabletSequence'
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_PENDING_OPERATIONS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_PENDING_OPERATIONS"]._serialized_options = b'\212\326\033\034\n\032TxProcessPendingOperations'
  _ETXTYPES.values_by_name["TXTYPE_MON_DB_STATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_DB_STATE"]._serialized_options = b'\212\326\033\016\n\014TxMonDbState'
  _ETXTYPES.values_by_name["TXTYPE_MON_MEM_STATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_MEM_STATE"]._serialized_options = b'\212\326\033\017\n\rTxMonMemState'
  _ETXTYPES.values_by_name["TXTYPE_MON_RESOURCES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_RESOURCES"]._serialized_options = b'\212\326\033\020\n\016TxMonResources'
  _ETXTYPES.values_by_name["TXTYPE_MON_SETTINGS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_SETTINGS"]._serialized_options = b'\212\326\033\017\n\rTxMonSettings'
  _ETXTYPES.values_by_name["TXTYPE_MON_LANDING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_LANDING"]._serialized_options = b'\212\326\033\016\n\014TxMonLanding'
  _ETXTYPES.values_by_name["TXTYPE_MON_LANDING_DATA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_LANDING_DATA"]._serialized_options = b'\212\326\033\022\n\020TxMonLandingData'
  _ETXTYPES.values_by_name["TXTYPE_MON_SET_DOWN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_SET_DOWN"]._serialized_options = b'\212\326\033\016\n\014TxMonSetDown'
  _ETXTYPES.values_by_name["TXTYPE_MON_SET_FREEZE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_SET_FREEZE"]._serialized_options = b'\212\326\033\020\n\016TxMonSetFreeze'
  _ETXTYPES.values_by_name["TXTYPE_MON_KICK_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_KICK_NODE"]._serialized_options = b'\212\326\033\017\n\rTxMonKickNode'
  _ETXTYPES.values_by_name["TXTYPE_MON_REBALANCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_REBALANCE"]._serialized_options = b'\212\326\033\020\n\016TxMonRebalance'
  _ETXTYPES.values_by_name["TXTYPE_MON_REASSIGN_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_REASSIGN_TABLET"]._serialized_options = b'\212\326\033\025\n\023TxMonReassignTablet'
  _ETXTYPES.values_by_name["TXTYPE_MON_RESET_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_RESET_TABLET"]._serialized_options = b'\212\326\033\022\n\020TxMonResetTablet'
  _ETXTYPES.values_by_name["TXTYPE_MON_GROUPS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_GROUPS"]._serialized_options = b'\212\326\033\r\n\013TxMonGroups'
  _ETXTYPES.values_by_name["TXTYPE_MON_NOT_READY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_NOT_READY"]._serialized_options = b'\212\326\033\017\n\rTxMonNotReady'
  _ETXTYPES.values_by_name["TXTYPE_MON_STORAGE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_STORAGE"]._serialized_options = b'\212\326\033\016\n\014TxMonStorage'
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_BOOT_QUEUE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_BOOT_QUEUE"]._serialized_options = b'\212\326\033\024\n\022TxProcessBootQueue'
  _ETXTYPES.values_by_name["TXTYPE_STATUS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STATUS"]._serialized_options = b'\212\326\033\n\n\010TxStatus'
  _ETXTYPES.values_by_name["TXTYPE_DISCONNECT_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DISCONNECT_NODE"]._serialized_options = b'\212\326\033\022\n\020TxDisconnectNode'
  _ETXTYPES.values_by_name["TXTYPE_MON_FIND_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_FIND_TABLET"]._serialized_options = b'\212\326\033\021\n\017TxMonFindTablet'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DOMAIN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DOMAIN"]._serialized_options = b'\212\326\033\020\n\016TxUpdateDomain'
  _ETXTYPES.values_by_name["TXTYPE_MON_STOP_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_STOP_TABLET"]._serialized_options = b'\212\326\033\021\n\017TxMonStopTablet'
  _ETXTYPES.values_by_name["TXTYPE_MON_RESUME_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_RESUME_TABLET"]._serialized_options = b'\212\326\033\023\n\021TxMonResumeTablet'
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE_SUBDOMAIN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE_SUBDOMAIN"]._serialized_options = b'\212\326\033\026\n\024TxConfigureSubdomain'
  _ETXTYPES.values_by_name["TXTYPE_MON_INIT_MIGRATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_INIT_MIGRATION"]._serialized_options = b'\212\326\033\024\n\022TxMonInitMigration'
  _ETXTYPES.values_by_name["TXTYPE_MON_QUERY_MIGRATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_QUERY_MIGRATION"]._serialized_options = b'\212\326\033\025\n\023TxMonQueryMigration'
  _ETXTYPES.values_by_name["TXTYPE_SEIZE_TABLETS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEIZE_TABLETS"]._serialized_options = b'\212\326\033\020\n\016TxSeizeTablets'
  _ETXTYPES.values_by_name["TXTYPE_SEIZE_TABLETS_REPLY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEIZE_TABLETS_REPLY"]._serialized_options = b'\212\326\033\025\n\023TxSeizeTabletsReply'
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_TABLETS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_TABLETS"]._serialized_options = b'\212\326\033\022\n\020TxReleaseTablets'
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_TABLETS_REPLY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_TABLETS_REPLY"]._serialized_options = b'\212\326\033\027\n\025TxReleaseTabletsReply'
  _ETXTYPES.values_by_name["TXTYPE_MON_DRAIN_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_DRAIN_NODE"]._serialized_options = b'\212\326\033\020\n\016TxMonDrainNode'
  _ETXTYPES.values_by_name["TXTYPE_MON_TABLET_INFO"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_TABLET_INFO"]._serialized_options = b'\212\326\033\021\n\017TxMonTabletInfo'
  _ETXTYPES.values_by_name["TXTYPE_START_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_START_TABLET"]._serialized_options = b'\212\326\033\017\n\rTxStartTablet'
  _ETXTYPES.values_by_name["TXTYPE_STOP_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STOP_TABLET"]._serialized_options = b'\212\326\033\016\n\014TxStopTablet'
  _ETXTYPES.values_by_name["TXTYPE_RESUME_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESUME_TABLET"]._serialized_options = b'\212\326\033\020\n\016TxResumeTablet'
  _ETXTYPES.values_by_name["TXTYPE_RESTART_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESTART_TABLET"]._serialized_options = b'\212\326\033\021\n\017TxRestartTablet'
  _ETXTYPES.values_by_name["TXTYPE_MON_MOVE_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_MOVE_TABLET"]._serialized_options = b'\212\326\033\021\n\017TxMonMoveTablet'
  _ETXTYPES.values_by_name["TXTYPE_TABLET_OWNERS_REPLY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_TABLET_OWNERS_REPLY"]._serialized_options = b'\212\326\033\025\n\023TxTabletOwnersReply'
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_TABLET_OWNERS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_TABLET_OWNERS"]._serialized_options = b'\212\326\033\027\n\025TxRequestTabletOwners'
  _ETXTYPES.values_by_name["TXTYPE_REASSIGN_GROUPS_ON_DECOMMIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REASSIGN_GROUPS_ON_DECOMMIT"]._serialized_options = b'\212\326\033\034\n\032TxReassignGroupsOnDecommit'
  _ESIMPLECOUNTERS._serialized_start=87
  _ESIMPLECOUNTERS._serialized_end=854
  _ECUMULATIVECOUNTERS._serialized_start=857
  _ECUMULATIVECOUNTERS._serialized_end=1502
  _EPERCENTILECOUNTERS._serialized_start=1504
  _EPERCENTILECOUNTERS._serialized_end=1582
  _ETXTYPES._serialized_start=1585
  _ETXTYPES._serialized_end=4822
# @@protoc_insertion_point(module_scope)



import ydb.core.protos.blobstorage_config_pb2 as kikimr_bsconfig
import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.table as table
from collections import defaultdict

description = 'List boxes'


def add_options(p):
    p.add_argument('--show-pdisk-status', action='store_true', help='Show columns with PDisk status')
    p.add_argument('--show-pdisk-usage', action='store_true', help='Show columns with PDisk usage')
    table.TableOutput([], col_units=[]).add_options(p)


def do(args):
    all_columns = [
        'BoxId',
        'DiskType',
        'PDisks_TOTAL',
        'PDisks_ACTIVE',
        'PDisks_INACTIVE',
        'PDisks_BROKEN',
        'PDisks_FAULTY',
        'PDisks_TO_BE_REMOVED',
        'Usage',
        'AvailableSize',
        'UsedSize',
        'TotalSize',
    ]
    visible_columns = [
        'BoxId',
        'DiskType',
        'PDisks_TOTAL',
    ]
    col_units = {
        'Usage': '%',
        'UsedSize': 'bytes',
        'AvailableSize': 'bytes',
        'TotalSize': 'bytes'
    }

    if args.show_pdisk_status or args.all_columns:
        visible_columns.extend(['PDisks_ACTIVE', 'PDisks_INACTIVE', 'PDisks_BROKEN', 'PDisks_FAULTY', 'PDisks_TO_BE_REMOVED'])

    if args.show_pdisk_usage or args.all_columns:
        visible_columns.extend(['Usage', 'AvailableSize', 'UsedSize', 'TotalSize'])

    table_output = table.TableOutput(all_columns, col_units=col_units, default_visible_columns=visible_columns)

    base_config = common.fetch_base_config()

    boxes = {}
    for pdisk in base_config.PDisk:
        if pdisk.BoxId not in boxes:
            boxes[pdisk.BoxId] = defaultdict(dict)

        if pdisk.Type not in boxes[pdisk.BoxId]:
            boxes[pdisk.BoxId][pdisk.Type] = defaultdict(int)

        box = boxes[pdisk.BoxId][pdisk.Type]

        for key in ['PDisks_TOTAL', 'PDisks_' + kikimr_bsconfig.EDriveStatus.Name(pdisk.DriveStatus)]:
            box[key] += 1

        box['TotalSize'] += pdisk.PDiskMetrics.TotalSize
        box['AvailableSize'] += pdisk.PDiskMetrics.AvailableSize
        box['UsedSize'] += (pdisk.PDiskMetrics.TotalSize - pdisk.PDiskMetrics.AvailableSize)

    rows = []
    for box_id, box_data in boxes.items():
        for disk_type, box in box_data.items():
            row = {}
            row['BoxId'] = box_id
            row['DiskType'] = kikimr_bsconfig.EPDiskType.Name(disk_type)

            for key, value in box.items():
                row[key] = value

            # set missing columns to 0
            for column in visible_columns:
                if column not in row:
                    row[column] = 0

            row['Usage'] = row['UsedSize'] / row['TotalSize'] if row['TotalSize'] != 0 else 0.0
            rows.append(row)

    table_output.dump(rows, args)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/common/proto/udf_resolver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9ydb/library/yql/providers/common/proto/udf_resolver.proto\x12\x04NYql\"?\n\tTFunction\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\x12\n\nTypeConfig\x18\x02 \x02(\t\x12\x10\n\x08UserType\x18\x03 \x01(\t\"D\n\nTArgResult\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\x0c\n\x04Type\x18\x02 \x02(\t\x12\x0b\n\x03\x44oc\x18\x03 \x02(\t\x12\r\n\x05\x46lags\x18\x04 \x02(\r\"\x90\x02\n\x0fTFunctionResult\x12\x1a\n\x12NormalizedUserType\x18\x01 \x01(\t\x12\x15\n\rRunConfigType\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llableType\x18\x03 \x01(\t\x12\r\n\x05\x45rror\x18\x04 \x01(\t\x12\x0c\n\x04Name\x18\x05 \x01(\t\x12\x0b\n\x03\x44oc\x18\x07 \x01(\t\x12\x17\n\x0fIsTypeAwareness\x18\x08 \x01(\x08\x12\x10\n\x08\x41rgCount\x18\t \x01(\r\x12\x18\n\x10OptionalArgCount\x18\n \x01(\r\x12\x1e\n\x04\x41rgs\x18\x0b \x03(\x0b\x32\x10.NYql.TArgResult\x12\x12\n\nReturnType\x18\x0c \x01(\t\x12\x11\n\tReturnDoc\x18\r \x01(\t\"Z\n\x07TImport\x12\x11\n\tFileAlias\x18\x01 \x02(\t\x12\x0c\n\x04Path\x18\x02 \x02(\t\x12\x15\n\x06System\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x17\n\x0f\x43ustomUdfPrefix\x18\x04 \x01(\t\"z\n\rTImportResult\x12\x11\n\tFileAlias\x18\x01 \x02(\t\x12\x0f\n\x07Modules\x18\x02 \x03(\t\x12\r\n\x05\x45rror\x18\x03 \x01(\t\x12\x10\n\x08\x46ileSize\x18\x04 \x01(\x04\x12\x0b\n\x03Md5\x18\x05 \x01(\t\x12\x17\n\x0f\x43ustomUdfPrefix\x18\x06 \x01(\t\"I\n\x08TResolve\x12\x1e\n\x07Imports\x18\x01 \x03(\x0b\x32\r.NYql.TImport\x12\x1d\n\x04Udfs\x18\x02 \x03(\x0b\x32\x0f.NYql.TFunction\"[\n\x0eTResolveResult\x12$\n\x07Imports\x18\x01 \x03(\x0b\x32\x13.NYql.TImportResult\x12#\n\x04Udfs\x18\x02 \x03(\x0b\x32\x15.NYql.TFunctionResultB\x15\n\x13ru.yandex.yql.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.common.proto.udf_resolver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023ru.yandex.yql.proto'
  _TFUNCTION._serialized_start=67
  _TFUNCTION._serialized_end=130
  _TARGRESULT._serialized_start=132
  _TARGRESULT._serialized_end=200
  _TFUNCTIONRESULT._serialized_start=203
  _TFUNCTIONRESULT._serialized_end=475
  _TIMPORT._serialized_start=477
  _TIMPORT._serialized_end=567
  _TIMPORTRESULT._serialized_start=569
  _TIMPORTRESULT._serialized_end=691
  _TRESOLVE._serialized_start=693
  _TRESOLVE._serialized_end=766
  _TRESOLVERESULT._serialized_start=768
  _TRESOLVERESULT._serialized_end=859
# @@protoc_insertion_point(module_scope)
